
# Spectator for Python

> :warning: Experimental

This is a Python port of the [Spectator] library for Java. Currently this is an experiment
to help determine the level of effort to support another language.

[Spectator]: https://github.com/Netflix/spectator/

## Requirements

* Python 2.7 or higher

## Links

* [Documentation](https://netflix.github.io/atlas-docs/)
* [![Build Status](https://travis-ci.org/Netflix/spectator-py.svg)](https://travis-ci.org/Netflix/spectator-py/builds)
